@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -69,21 +69,6 @@
 		}							\
 	} while (0)
 
-
-static void display_self_times(void)
-{
-	printf("-- Overview using `ps` --------------------"
-	       "---------------\n");
-	printf("-- this client is %8u ----------------"
-	       "---------------\n", (unsigned)getpid());
-	printf("-- this server is %8u ----------------"
-	       "---------------\n", (unsigned)glibtop_global_server->pid);
-	system("ps xjf | egrep 'timings|libgtop_server'");
-	printf("-------------------------------------------"
-	       "---------------\n");
-}
-
-
 int
 main (int argc, char *argv [])
 {
@@ -100,16 +85,13 @@ main (int argc, char *argv [])
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
 
-
-	glibtop_init_r (&glibtop_global_server, 0, 0);
-
-	display_self_times();
-
 	printf ("%-12s (%-10s): %7s - %9s - %9s\n",
 		"Feature", "Flags", "Count", "utime", "stime");
 	printf ("-------------------------------------------"
 		"---------------\n");
 
+	glibtop_init_r (&glibtop_global_server, 0, 0);
+
 	getrusage (RUSAGE_SELF, &total_start);
 
 	getrusage (RUSAGE_SELF, &rusage_start);
@@ -412,26 +394,6 @@ main (int argc, char *argv [])
 		(long double) ELAPSED_UTIME / PROFILE_COUNT,
 		(long double) ELAPSED_STIME / PROFILE_COUNT);
 
-
-	getrusage (RUSAGE_SELF, &rusage_start);
-
-	for (c = 0; c < PROFILE_COUNT; c++)
-		glibtop_get_proc_io (&data.proc_io, pid);
-
-	getrusage (RUSAGE_SELF, &rusage_end);
-
-	libgtop_timersub (&rusage_end.ru_utime, &rusage_start.ru_utime,
-			  &elapsed_utime);
-
-	libgtop_timersub (&rusage_end.ru_stime, &rusage_start.ru_stime,
-			  &elapsed_stime);
-
-	printf ("Proc_Io  (0x%08lx): %7lu - %9.2Lf - %9.2Lf\n",
-		(unsigned long) data.proc_io.flags, PROFILE_COUNT,
-		(long double) ELAPSED_UTIME / PROFILE_COUNT,
-		(long double) ELAPSED_STIME / PROFILE_COUNT);
-
-
 	getrusage (RUSAGE_SELF, &total_end);
 
 	libgtop_timersub (&total_end.ru_utime, &total_start.ru_utime,
@@ -449,8 +411,6 @@ main (int argc, char *argv [])
 	printf ("All timings are in clock ticks "
 		"(1000000 ticks per second).\n\n");
 
-	display_self_times();
-
 	glibtop_close ();
 
 	exit (0);
