@@ -1,3 +1,5 @@
+/* $OpenBSD: procargs.c,v 1.3 2011/05/23 19:35:54 jasper Exp $	*/
+
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
 
@@ -15,8 +17,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
@@ -56,26 +58,24 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 
 	memset (buf, 0, sizeof (glibtop_proc_args));
 
-	/* Ignore init */
-	if (pid < 2) return NULL;
+	/*
+	 * Don't bother with PIDs below 20, because everything below this
+	 * number is highly likely to be a kernel thread.
+	 */
+	if (pid < 19) return NULL;
 
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
-	pinfo = kvm_getprocs (server->machine->kd, KERN_PROC_PID, pid,
+	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid,
 			       sizeof (*pinfo), &count);
-	if (pinfo == NULL) {
+	if ((pinfo == NULL) || (count < 1)) {
 		glibtop_suid_leave (server);
 		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
 		return NULL;
 	}
 
-	if (pinfo[0].p_flag & P_SYSTEM) {
-		glibtop_suid_leave (server);
-		return NULL;
-	}
-
-	args = kvm_getargv (server->machine->kd, pinfo, max_len);
+	args = kvm_getargv (server->machine.kd, pinfo, max_len);
 	if (args == NULL) {
 		glibtop_suid_leave (server);
 		glibtop_warn_io_r (server, "kvm_getargv (%d)", pid);
